SYNC_TYPE_CAL = 0
SYNC_TYPE_CONTACTS = 1

DATASOURCE_BUILTIN = 0
DATASOURCE_GPE = 1

DIRECTION_BOTH = 0
DIRECTION_TO_GOOGLE_ONLY = 1
DIRECTION_FROM_GOOGLE_ONLY = 2

INVALID_USER_PWD = 0
NO_INET_CONNECTION = 1
